/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

#include <klocale.h>
#include <kaction.h>
#include <kstdaction.h>
#include <kaccel.h>
#include <kstdaccel.h>
#include <kapplication.h>
#include <kpopupmenu.h>
#include "actioncollection.h"
#include "kmusicmanager.h"
#include "mainwindow.h"
#include "player/musicplayer.h"
#include "musicdb/musicdatabase.h"

ActionCollection::ActionCollection(QObject *parent, const char *name)
	: QObject(parent,name)
{
	m_toolbar_action = 0;
	m_statusbar_action = 0;
	m_add_files = 0;
	m_add_dir = 0;
	m_man_db = 0;
	
	m_play = 0;
	m_pause = 0;
	m_stop = 0;
	m_next = 0;
	m_prev = 0;
	m_random_play = 0;
	m_repeat_playlist = 0;
}


ActionCollection::~ActionCollection()
{}

void ActionCollection::createActions(KMusicManager* musicman,MainWindow* wnd)
{
	MusicPlayer* player = musicman->getPlayer();
	
	KStdAction::quit(musicman, SLOT(quit()), wnd->actionCollection());;
	

	m_toolbar_action = KStdAction::showToolbar(
			wnd, SLOT(optionsShowToolbar()), wnd->actionCollection());
	
	m_statusbar_action = KStdAction::showStatusbar(
			wnd, SLOT(optionsShowStatusbar()), wnd->actionCollection());

	KStdAction::keyBindings(
			wnd, SLOT(optionsConfigureKeys()), wnd->actionCollection());
	
	KStdAction::configureToolbars(
			wnd, SLOT(optionsConfigureToolbars()), wnd->actionCollection());
	
	KStdAction::preferences(wnd, SLOT(optionsPreferences()), wnd->actionCollection());

	
	m_add_files = new KAction(i18n("Add Files"),"fileopen",KStdAccel::open(),
			musicman,SLOT(fileAddFiles()),wnd->actionCollection(),"add_files");
	
	m_add_dir = new KAction(i18n("Add Directory"),"fileimport",CTRL+SHIFT+Key_O,
			musicman,SLOT(fileAddDir()),wnd->actionCollection(),"add_directory");
	
	m_man_db = new KAction(i18n("Manage Directories"),CTRL+Key_D,
			musicman,SLOT(fileManDirs()),wnd->actionCollection(),"man_db");
			
	m_play = new KAction(
		i18n("Play"),
		"player_play",
		0,player,SLOT(play()),wnd->actionCollection(),"play");
	
	m_pause = new KAction(i18n("Pause"),
		"player_pause",
		0,player,SLOT(pause()),wnd->actionCollection(),"pause");
	
	m_stop = new KAction(i18n("Stop"),
		"player_stop",
		0,player,SLOT(stop()),wnd->actionCollection(),"stop");
	
	m_next = new KAction(i18n("Next"),
		"player_end",
		0,player,SLOT(next()),wnd->actionCollection(),"next");
	
	m_prev = new KAction(i18n("Previous"),
		"player_start",
		0,player,SLOT(prev()),wnd->actionCollection(),"prev");
	
	m_random_play = new KToggleAction(i18n("Random Play"),0,
									  wnd->actionCollection(),"random_play");
	
	connect(m_random_play,SIGNAL(toggled(bool )),player,SLOT(setRandom(bool )));
	
	m_repeat_playlist = new KToggleAction(i18n("Repeat Playlist"),0,
										  wnd->actionCollection(),"loop_playlist");
	
	connect(m_repeat_playlist,SIGNAL(toggled(bool )),player,SLOT(setRepeat(bool )));
	
	connect(player,SIGNAL(setNextEnabled(bool )),m_next,SLOT(setEnabled(bool )));
	connect(player,SIGNAL(setPauseEnabled(bool )),m_pause,SLOT(setEnabled(bool )));
	connect(player,SIGNAL(setPlayEnabled(bool )),m_play,SLOT(setEnabled(bool )));
	connect(player,SIGNAL(setPrevEnabled(bool )),m_prev,SLOT(setEnabled(bool )));
	connect(player,SIGNAL(setStopEnabled(bool )),m_stop,SLOT(setEnabled(bool )));
	
	m_pause->setEnabled(false);
	m_stop->setEnabled(false);
	m_prev->setEnabled(false);
}

void ActionCollection::buildSysTrayMenu(KPopupMenu* menu)
{
	m_play->plug(menu,1);
	m_pause->plug(menu,2);
	m_stop->plug(menu,3);
	menu->insertSeparator(4);
	m_prev->plug(menu,5);
	m_next->plug(menu,6);
	menu->insertSeparator(7);
	m_random_play->plug(menu,8);
	m_repeat_playlist->plug(menu,9);
}

#include "actioncollection.moc"
