/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@student.luc.ac.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef DBDIR_H
#define DBDIR_H

#include <qmap.h>
#include <qobject.h>
#include <kfileitem.h>

class Song;
class MusicDatabase;
class KDirLister;


/**
@author Joris Guisson
*/
class DBDir : public QObject
{
	Q_OBJECT

	DBDir* m_parent;
	QString m_path,m_name;
	MusicDatabase* m_db;
	KDirLister* m_lister;
	QMap<QString,DBDir*> m_children;

public:
	DBDir(MusicDatabase* db,DBDir* parent,const QString & path,const QString & name);
	virtual ~DBDir();

	QString getDirName() const {return m_name;}
	QString getDirPath() const {return m_path;}
	QString getFullPath() const {return m_path + m_name;}

	void setDirName(const QString & name);

	DBDir* getParent() {return m_parent;}
	
	void clear();

public slots:
	void rescan();


private slots:
	void onListerCompleted();
	void onNewItems(const KFileItemList &items);
	void onDeleteItem(KFileItem* fileItem);
	void onRefreshItems(const KFileItemList &items);

private:
	void addSong(KFileItem* fi);
	void addDir(KFileItem* fi);
	void refreshSong(KFileItem* fi);
	void refreshDir(KFileItem* fi);
};

#endif
