/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 ***************************************************************************/
#include <algorithm>
#include <qdir.h>
#include <qstringlist.h>
#include <qfile.h>
#include <qfileinfo.h>
#include <qtextstream.h>
#include <stdlib.h>
#include <qapplication.h>
#include "musicdatabase.h"
#include "song.h"
#include "util/error.h"
#include "musicdbimporter.h"
#include "musicdbexporter.h"
#include "filescanthread.h"
#include "dbdir.h"
#include "globals.h"


MusicDatabase::MusicDatabase(QObject* parent,const char* name) : QObject(parent,name)
{
//	m_fscan = new FileScanThread();
}


MusicDatabase::~MusicDatabase()
{
	clear();
//	m_fscan->stop();
//	m_fscan->wait();
//	delete m_fscan;
}

void MusicDatabase::addSong(Song* s,bool scan)
{
	if (!s || getSong(s->getFilename()))
		return;
	
	m_files.insert(s->getFilename(),s);
//	m_fscan->addSong(s);
	if (scan)
		s->loadInfoFromFile();
	
	songAdded(s);
	if (scan)
		qApp->processEvents();
}

Song* MusicDatabase::getSong(const QString & fn)
{
	SongItr itr = m_files.find(fn);
	return itr == m_files.end() ? 0 : itr.data();
}

void MusicDatabase::renameDir(const QString & old_name,const QString & new_name)
{
	DBDirItr i = m_db_dirs.find(old_name);
	if (i == m_db_dirs.end())
		return;
	
	DBDir* d = i.data();
	QString p = d->getDirPath();
	
	m_db_dirs.erase(i);
	m_db_dirs.insert(new_name,d);
	
	d->setDirName(new_name.mid(p.length()));
}

Song* MusicDatabase::renameSong(const QString & fn,const QString & new_name)
{
	SongItr i = m_files.find(fn);
	if (i == m_files.end())
		return 0;
	
	
	Song* s = i.data();
	m_files.erase(i);
	s->setFilename(new_name);
	m_files.insert(s->getFilename(),s);
	
	s->emitModified();
	return s;
}

void MusicDatabase::removeSong(const QString & fn)
{
	SongItr itr = m_files.find(fn);
	if (itr == m_files.end())
		return;
	
	songGoingToBeRemoved(itr.data());
	delete itr.data();
	m_files.erase(itr);
}

void MusicDatabase::clear()
{
	SongItr itr = m_files.begin();
	while (itr != m_files.end())
	{
		delete itr.data();
		++itr;
	}
	m_files.clear();
}

void MusicDatabase::addDir(const QString & dir)
{
	QDir d(dir);
	if (!d.exists())
		return;
	
	QString name = d.dirName();
	QString path = dir.left(dir.length() - name.length());
	DBDir* dbd = new DBDir(this,0,path,name);
	addDir(dbd);
//	m_fscan->start();
}

void MusicDatabase::addDir(DBDir* d)
{
	if (m_db_dirs.find(d->getFullPath()) != m_db_dirs.end())
		return;
	
	m_db_dirs[d->getFullPath()] = d;
	dirAdded(d);
}

void MusicDatabase::removeDir(const QString & dir)
{
	DBDirItr i = m_db_dirs.find(dir);
	if (i != m_db_dirs.end())
	{
		i.data()->clear();
		dirRemoved(i.data());
		delete i.data();
		m_db_dirs.erase(i);
	}
}


void MusicDatabase::saveDB(const QString & file)
{
	MusicDBExporter exp(this);
	exp.exportDB(file);
}

void MusicDatabase::loadDB(const QString & file)
{
	try
	{
		MusicDBImporter imp(this);
		imp.importDB(file);
		OutputLog() << "Making backup copy of database" << endl;
		QString comm = QString("cp %1 %2").arg(file).arg(file + ".backup");
		system(comm.ascii());
	}
	catch (Error & e)
	{
		OutputLog() << "Cannot open main file, trying backup" << endl;
		MusicDBImporter imp(this);
		imp.importDB(file + ".backup");
	}
}


#include "musicdatabase.moc"
