/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 ***************************************************************************/
#ifndef SONG_H
#define SONG_H

#include <qstring.h>
#include <qobject.h>



/**
@author Joris Guisson
@brief Class which keeps track of a Song

This class keeps track of all the info a song has.
*/
class Song : public QObject
{
	Q_OBJECT
	
	QString filename;
	QString title;
	QString artist;
	QString album;
	int album_nr;
	int length;
	int year;
	QString genre;
	QString dir;
	QString comment;
	unsigned int last_mod;
public:
	/**
		Constructor. This doesn't read the info from the
		file.
		@param filename The filename of the song
	*/
	Song(const QString & filename);
	
	/**
		Copy constructor.
		@param s The Song
	*/
	Song(const Song & s);
	
	/**
		Destructor.
	*/
	virtual ~Song();

	/**
		Get the directory in which the song is located.
	*/
	QString getDirectory() const {return dir;}
	
	/**
		Set the time at which the song was last modified on disk.
	*/
	void setLastModified(unsigned int lm) {last_mod = lm;}
	
	/**
		See if the song was modified on disk.
	*/
	bool isModifiedOnDisk() const;
	
	/**
		See if the song exists on disk.
	*/
	bool existsOnDisk() const;
	
	/// Get the filename of the song.
	QString getFilename() const {return filename;}
	
	/// Set the filename of the song.
	void setFilename(const QString & fn) {filename = fn;}
	
	QString getTitle() const {return title;}
	void setTitle(const QString & t) {title = t;}
	
	QString getArtist() const {return artist;}
	void setArtist(const QString & a) {artist = a;}
	
	QString getAlbum() const {return album;}
	void setAlbum(const QString & a) {album = a;}
	
	int getAlbumNr() const {return album_nr;}
	void setAlbumNr(int n) {album_nr = n;}
	
	int getLength() const {return length;}
	void setLength(int l) {length = l;}
	
	int getYear() const {return year;}
	void setYear(int y) {year = y;}
	
	QString getGenre() const {return genre;}
	void setGenre(const QString & g) {genre = g;}
	
	QString getFileExtension() const;
	
	/**
		See if this Song matches a filter. This function
		will check wether all properties of the song contain
		the filter string.
		@param filter The filter string
	*/
	bool matchesFilter(const QString & filter);
	
	void setComment(const QString & c) {comment = c;}
	QString getComment() const {return comment;}
	
public slots:
	/**
		Read the songs properties from it's file.
		@return true upon succes, false otherwise
	*/
	bool loadInfoFromFile();
	
	/**
		Write the songs properties to it's file.
		@return true upon succes, false otherwise
	*/
	bool saveInfoToFile();
	
	/**
	 * Emit the modified signal.
	 */
	void emitModified();
signals:
	/**
		Signal emitted when some property is modified.
	*/
	void modified();

	/**
	 * Signal emitted when some property is modified, the song is passed
	 * a long.
	 */
	void modified(Song* song);
};

#endif
