/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@student.luc.ac.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef ARTSPLAYER_H
#define ARTSPLAYER_H


#include <arts/artsflow.h>
#include "player/playerbase.h"

class KArtsDispatcher;
class KArtsServer;
class KAudioManagerPlay;

namespace KDE
{
	class PlayObjectFactory;
	class PlayObject;
}


/**
@author Joris Guisson
@brief Player which uses aRts
			   
This is an implemntation of a player which uses aRts to
do it's work.
*/
class ArtsPlayer : public PlayerBase
{
	Q_OBJECT
	
	KArtsDispatcher* m_dispatcher;
	KArtsServer* m_server;
	KDE::PlayObjectFactory* m_factory;
	KDE::PlayObject* m_curr;
	KAudioManagerPlay* m_aman_play;
	
	Arts::StereoVolumeControl m_volume_ctrl;
	 
	bool m_paused;
	float m_volume;
	
	void setupVolumeControl();
	
private slots:
	void setupArtsObjects();
	void playObjectCreated();
	
public:
	ArtsPlayer(QObject *parent = 0, const char *name = 0);
	virtual ~ArtsPlayer();
	
	int totalTime() const;
	int currentTime() const;
	bool isIdle() const;
	bool isPaused() const {return m_paused;}
	bool isPlaying() const;
	bool isServerRunning() const;
	
	bool play(const QString & file);
	bool resume();
	bool pause();
	bool stop();
	void seek(int secs);
	float setVolume(float vol);
};

#endif
