/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@student.luc.ac.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/

 
#include "gstplayer.h"
#include "gstplaythread.h"

#ifdef HAVE_GSTREAMER

GstPlayer::GstPlayer(QObject* parent, const char* name): PlayerBase(parent, name)
{
	m_pt = new GstPlayThread();
}


GstPlayer::~GstPlayer()
{
	if (m_pt->isPlaying())
	{
		m_pt->stop();
	}
	m_pt->wait();
	delete m_pt;
}


bool GstPlayer::isIdle() const
{
	return m_pt->isIdle();
}

bool GstPlayer::isPaused() const
{
	return m_pt->isPaused();
}

bool GstPlayer::isPlaying() const
{
	return m_pt->isPlaying();
}

bool GstPlayer::pause()
{
	m_pt->pause();
	return true;
}

bool GstPlayer::play(const QString& file)
{
	m_pt->play(file.ascii());
	m_pt->start();
	return true;
}

bool GstPlayer::resume()
{
	m_pt->resume();
	return true;
}

bool GstPlayer::stop()
{
	m_pt->stop();
	return true;
}

float GstPlayer::setVolume(float vol)
{
	return m_pt->setVolume(vol);
}

int GstPlayer::currentTime() const
{
	return m_pt->currentTime();
}

int GstPlayer::totalTime() const
{
	return 0;
}

void GstPlayer::seek(int secs)
{
	m_pt->seek(secs);
}

#include "gstplayer.moc"

#endif
