/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@student.luc.ac.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef PLAYERFACTORY_H
#define PLAYERFACTORY_H

#include <qstring.h>
#include "playerbase.h"

/**
@author Joris Guisson
@brief Produces PlayerBase objects

This class produces PlayerBase objects, it will allow
the use of multiple media backends (aRts,GStreamer,xine, ...).
Each media backend should register an instance with the
MusicPlayer.

A PlayerFactory has 3 string objects as data : 
- a short name used internally by the system
- a descriptive name shown in the configuration dialog (so that the user can select different backends)
- a description which will also be shown in the configuration dialog
*/
class PlayerFactory
{
	QString m_name;
	QString m_descriptive_name;
	QString m_description;
public:
	/**
	 * Constructor, initialize the 3 strings of the object.
	 * @param name Short name
	 * @param descriptive_name Descriptive name
	 * @param description Description
	 */
	PlayerFactory(
		const QString & name,
		const QString & descriptive_name,
		const QString & description);
	
	virtual ~PlayerFactory();
	
	QString getName() const {return m_name;}
	QString getDescriptiveName() const {return m_descriptive_name;}
	QString getDescription() const {return m_description;}
	
	/**
	 * Create a PlayerBase object, do not return 0. Allways throw
	 * an exception when an error occurs.
	 * @return A newly created object
	 */
	virtual PlayerBase* createPlayer() = 0;
};

#endif
