/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 ***************************************************************************/
#include <algorithm>
#include "playqueue.h"
#include "musicdb/song.h"
#include "musicdb/musicdatabase.h"

PlayQueue::PlayQueue(MusicDatabase* mdb) : PlayList("PlayQueue",mdb)
{}


PlayQueue::~PlayQueue()
{
}

void PlayQueue::enqueue(Song* s)
{
	if (!s)
		return;
	
	appendSong(s);
}

Song* PlayQueue::dequeue()
{
	if (songs.empty())
		return 0;
	
	Song* s = songs.front();
	songs.pop_front();
	changed();
	return s;
}


void PlayQueue::insertAfter(int index,Song* s)
{
	if (index < 0)
	{
		songs.push_front(s);
	}
	else
	{
		int i = 0;
		std::list<Song*>::iterator itr = songs.begin();
		while (i <= index && itr != songs.end())
		{
			i++;
			itr++;
		}
		songs.insert(itr,s);
	}
	
	changed();
}

void PlayQueue::removeItem(int index)
{
	int i = 0;
	std::list<Song*>::iterator itr = songs.begin();
	while (i < index && itr != songs.end())
	{
		i++;
		itr++;
	}
	if (itr != songs.end())
		songs.erase(itr);
	
	changed();
}

void PlayQueue::removeItems(const std::list<int> & indices)
{
	std::list<Song*>::iterator itr = songs.begin();
	int i = 0;
	while (itr != songs.end())
	{
		if (std::find(indices.begin(),indices.end(),i) != indices.end())
			itr = songs.erase(itr);
		else
			itr++;
		
		i++;
	}
	changed();
}

void PlayQueue::saveQueue(const QString & dir)
{
	save(dir + "playqueue");
}

void PlayQueue::loadQueue(const QString & dir,MusicDatabase* mdb)
{
	load(dir + "playqueue",mdb);
}


#include "playqueue.moc"

