/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 ***************************************************************************/
#include <kstatusbar.h>
#include <klocale.h>
#include <qlabel.h>
#include "statusbar.h"
#include "view/musiclistviewinfolabel.h"
#include "musicdb/musicdatabase.h"
#include "musicdb/song.h"
#include "player/timedisplaylabel.h"
#include "player/musicplayer.h"
#include "kmusicmanager.h"
#include "mainwindow.h"


MMStatusBar::MMStatusBar(KMusicManager* mm,MainWindow* wnd,const char *name)
	: QObject(wnd, name),mm(mm)
{
	KStatusBar* sb = wnd->statusBar();
	
	m_curr_song = new QLabel(i18n("Nothing playing"),wnd);
	m_time_display = new TimeDisplayLabel(wnd);
	m_view_info_label = new MusicListViewInfoLabel(wnd);
	
	sb->addWidget(m_curr_song,0,true);
	sb->addWidget(m_time_display,0,true);
	sb->addWidget(m_view_info_label,0,true);
	
	MusicPlayer* player = mm->getPlayer();
	
	connect(
		player,SIGNAL(elapsed(int)),
		m_time_display,SLOT(setCurrentTime(int )));
	
	connect(
		player,SIGNAL(totalSongTimeChanged(int)),
		m_time_display,SLOT(setTotalTime(int )));
	
	connect(
		wnd,SIGNAL(filtered(int, int )),
		m_view_info_label,SLOT(onFiltered(int, int )));
	
	connect(player,SIGNAL(playing(const QString& )),this,SLOT(onPlayingSong(const QString& )));
	sb->show();
}


MMStatusBar::~MMStatusBar()
{}

void MMStatusBar::onPlayingSong(const QString & filename)
{
	Song* s = mm->getMusicDB()->getSong(filename);
	if (s)
	{
		m_curr_song->setText(QString("%1 - %2").arg(s->getArtist()).arg(s->getTitle()));
	}
	else
	{
		m_curr_song->setText(filename);
	}
}

#include "statusbar.moc"
