/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "album.h"
#include "musicdb/song.h"

Album::Album(const QString & name,const QString & artist,MusicDatabase* mdb)
	: PlayList(name,mdb),m_artist(artist)
{}


Album::~Album()
{
}

int Album::getTotalLength() const
{
	int time = 0;
	for (const_iterator i = begin();i != end();i++)
	{
		const Song* s = *i;
		if (s)
			time += s->getLength();
	}
	return time;
}

bool Album::contains(Song* s)
{
	for (iterator i = begin();i != end();i++)
		if (*i == s)
			return true;
	
	return false;
}

void Album::songModified(Song* s)
{
	if (s->getAlbum() != getName() || s->getArtist() != m_artist)
		removeSong(s);
}

void Album::appendSong(Song* s)
{
	PlayList::appendSong(s);
	connect(s,SIGNAL(modified(Song* )),this,SLOT(songModified(Song* )));
}

void Album::prependSong(Song* s)
{
	PlayList::prependSong(s);
	connect(s,SIGNAL(modified(Song* )),this,SLOT(songModified(Song* )));
}

void Album::removeSong(Song* s)
{
	PlayList::removeSong(s);
	disconnect(s,SIGNAL(modified(Song* )),this,SLOT(songModified(Song* )));
	if (empty())
		emptyAlbum(this);
}

#include "album.moc"

