/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "albumdb.h"
#include "musicdb/musicdatabase.h"
#include "musicdb/song.h"
#include "util/functions.h"

AlbumDB::AlbumDB(MusicDatabase* db,QObject *parent, const char *name)
	: QObject(parent, name),m_db(db)
{
	connect(db,SIGNAL(songAdded(Song*)),this,SLOT(songAdded(Song*)));
}


AlbumDB::~AlbumDB()
{
	for (AlbumItr i = m_albums.begin();i != m_albums.end();i++)
		delete i->second;
	Destroy(m_empty.begin(),m_empty.end());
}

Album* AlbumDB::getAlbum(const QString & key)
{
	AlbumItr i = m_albums.find(key);
	return i == m_albums.end() ? 0 : i->second;
}

void AlbumDB::newAlbum(Song* s)
{
	QString key = s->getAlbum() + ":" + s->getArtist();
	Album* a = new Album(s->getAlbum(),s->getArtist(),m_db);
	m_albums[key] = a;
	albumAdded(a);
	connect(a,SIGNAL(emptyAlbum(Album* )),this,SLOT(albumEmpty(Album* )));
	a->appendSong(s);
}
		
void AlbumDB::scan()
{
	for (SongItr i = m_db->beginSongs();i != m_db->endSongs();i++)
	{
		Song* s = i.data();
		songAdded(s);
	}
}

void AlbumDB::albumEmpty(Album* album)
{
	albumRemoved(album);
	m_empty.push_back(album);
	m_albums.erase(album->getKey());
}

void AlbumDB::songWasModified(Song* s)
{
	if (s->getAlbum().isNull() || s->getAlbum().isEmpty())
		return;
		
	Album* a = getAlbum(s->getAlbum() + ":" + s->getArtist());
	if (a)
	{
		if (!a->contains(s))
			a->appendSong(s);
	}
	else
	{
		newAlbum(s);
	}
}

void AlbumDB::songAdded(Song* s)
{
	connect(s,SIGNAL(modified(Song*)),this,SLOT(songWasModified(Song*)));
	if (s->getAlbum().isNull() || s->getAlbum().isEmpty())
		return;
		
	Album* a = getAlbum(s->getAlbum() + ":" + s->getArtist());
	if (a)
	{
		if (!a->contains(s))
			a->appendSong(s);
	}
	else
	{
		newAlbum(s);
	}

}

#include "albumdb.moc"
