/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@student.luc.ac.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <kconfig.h>
#include "filerenamer.h"
#include "renamedialog.h"

#include "view/childview.h"
#include "view/musiclistview.h"

#include "musicdb/song.h"
#include "musicdb/musicdatabase.h"
#include "kmusicmanager.h"


FileRenamer::FileRenamer(KMusicManager* mm, const char *name)
	: Tool("tool/filerenamer",mm, name),m_dlg(0)
{}


FileRenamer::~FileRenamer()
{}

void FileRenamer::load()
{
	if (!m_dlg)
	{
		m_dlg = new RenameDialog(getMusicMan()->getMusicDB());
	}
}

void FileRenamer::unload()
{
	if (m_dlg)
	{
		delete m_dlg;
		m_dlg = 0;
	}
}

void FileRenamer::onChildViewAdded(ChildView* cv)
{
	connect(cv->getMusicListView(),SIGNAL(rename(const std::list< Song * >& )),
			this,SLOT(rename(const std::list< Song * >& )));
}

void FileRenamer::rename(const std::list<Song*> & songs)
{
	m_dlg->setSongs(songs);
	m_dlg->show();
	m_dlg->exec();
}

void FileRenamer::rename(Song* s)
{
	std::list<Song*> songs;
	songs.push_back(s);
	rename(songs);
}

void FileRenamer::saveSettings(KConfig* cfg)
{
	cfg->setGroup(getToolName());
	cfg->writeEntry("rename_scheme",m_dlg->getRenameScheme());
}

void FileRenamer::loadSettings(KConfig* cfg)
{
	cfg->setGroup(getToolName());
	m_dlg->setRenameScheme(cfg->readEntry("rename_scheme","$A - $T"));
}

#include "filerenamer.moc"
