/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@student.luc.ac.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <set> 
#include <qdir.h>
#include <klineedit.h>
#include <qstringlist.h>
#include "renamedialog.h"
#include "renamefileitem.h"
#include "musicdb/song.h"
#include "musicdb/musicdatabase.h"
#include "util/iojobscheduler.h"
#include "util/iorenamejob.h"
#include "util/iomakedirjob.h"


RenameDialog::RenameDialog(MusicDatabase* db,QWidget *parent, const char *name)
	: RenameDialogBase(parent, name),m_db(db)
{
	m_rename_scheme = "$A - $T";
	m_rename_method->setText(m_rename_scheme);
}

RenameDialog::~RenameDialog()
{
	clear();
}

void RenameDialog::setRenameScheme(const QString & str)
{
	m_rename_scheme = str;
	m_rename_method->setText(str);
}

void RenameDialog::clear()
{
	for (RFItr i = m_songs.begin();i != m_songs.end();i++)
		delete i->second;
	
	m_songs.clear();
}

void RenameDialog::setSongs(const std::list<Song*> & songs)
{
	clear();
	
	typedef std::list<Song*>::const_iterator SItr;
	
	for (SItr i = songs.begin();i != songs.end();i++)
	{
		RenameFileItem* rfi = new RenameFileItem(*i,m_file_view);
		m_songs[*i] = rfi;
		rfi->renameStringChanged(m_rename_scheme);
	}
}

void RenameDialog::onRenameStringChanged(const QString & s)
{
	m_rename_scheme = s;
	for (RFItr i = m_songs.begin();i != m_songs.end();i++)
		i->second->renameStringChanged(m_rename_scheme);
}

void RenameDialog::onRenamePressed()
{
	IOJobScheduler & sched = IOJobScheduler::instance();
	std::list<std::pair<QString,QString> > rn;
	typedef std::list<std::pair<QString,QString> >::iterator RNItr;
	
	std::set<QString> dirs_to_make;
	
	for (RFItr i = m_songs.begin();i != m_songs.end();i++)
	{
		Song* s = i->first;
		QString nn = NewName(s,m_rename_scheme);
		if (nn != s->getFilename())
		{
			rn.push_back(std::make_pair(s->getFilename(),nn));
			m_db->renameSong(s->getFilename(),nn);
		}
	}
	
	for (RNItr i = rn.begin();i != rn.end();i++)
	{
		QDir dir;
		QStringList p = QStringList::split("/",i->second);
		
		QString path = "/";
		unsigned int j = 0;
		while (j < p.size() - 1)
		{
			path += *p.at(j);
			j++;
			if (!dir.exists(path,true))
			{
				dirs_to_make.insert(path);
			}
			path += "/";
		}
	}
	
	for (std::set<QString>::iterator i = dirs_to_make.begin();i != dirs_to_make.end();i++)
	{
		sched.addJob(new IOMakeDirJob(*i));
	}
	
	for (RNItr i = rn.begin();i != rn.end();i++)
	{
		sched.addJob(new IORenameJob(i->first,i->second));
	}
	close();
}

#include "renamedialog.moc"
