/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 ***************************************************************************/
#include <qfile.h>
#include <qtextstream.h>
#include <algorithm>
#include "playlist.h"
#include "musicdb/song.h"
#include "musicdb/musicdatabase.h"
#include "globals.h"

PlayList::PlayList(const QString & name,MusicDatabase* mdb) : name(name)
{
	connect(mdb,SIGNAL(songGoingToBeRemoved(Song* )),this,SLOT(onSongRemoved(Song* )));
}


PlayList::~PlayList()
{}

void PlayList::autosave()
{
	OutputLog() << "Autosaving playlist " << name << endl;
	if (!save(filename))
	{
		OutputLog() << "Cannot save to file " << filename << endl;
	}
}

void PlayList::appendSong(Song* s)
{
	if (!s) return;
	songs.push_back(s);
	changed();
	songAdded(s);
}

void PlayList::prependSong(Song* s)
{
	if (!s) return;
	songs.push_front(s);
	changed();
	songAdded(s);
}

void PlayList::removeSong(Song* s)
{
	if (!s) return;
	songs.remove(s);
	changed();
	songRemoved(s);
}

bool PlayList::save(const QString & fn)
{
	QFile file(fn);
	if (!file.open(IO_WriteOnly))
	{
		OutputLog() << "Cannot open file " << 
			filename << " : " << file.errorString() << endl;
		return false;
	}
	
	QTextStream out(&file);
	
	std::list<Song*>::iterator itr = songs.begin();
	while (itr != songs.end())
	{
		Song* s = *itr;
		out << s->getFilename() << "\n";
		++itr;
	}
	setFilename(fn);
	return true;
}

bool PlayList::load(const QString & fn,MusicDatabase* mdb)
{
	QFile file(fn);
	if (!file.open(IO_ReadOnly))
	{
		OutputLog() << "Cannot open file " << fn << " : " << file.errorString() << endl;
		return false;
	}
	
	QTextStream in(&file);
	while (!in.atEnd())
	{
		QString fn = in.readLine();
		Song* s = mdb->getSong(fn);
		if (s)
		{
			songs.push_back(s);
			songAdded(s);
		}
		else
		{
			OutputLog() << "Song " << fn << " doesn't exist any more !" << endl;
		}
	}
	
	changed();
	setFilename(fn);
	return true;
}

void PlayList::onSongRemoved(Song* s)
{
	iterator i = std::find(begin(),end(),s);
	if (i != end())
	{
		removeSong(s);
		songRemoved(s);
		autosave();
	}
}

#include "playlist.moc"
