/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 ***************************************************************************/
#ifndef PLAYLIST_H
#define PLAYLIST_H


#include <qobject.h>
#include <list>

class Song;
class MusicDatabase;

/**
@author Joris Guisson
*/
class PlayList : public QObject
{
	Q_OBJECT

protected:
	QString name;
	QString filename;
	std::list<Song*> songs;
	
public:
	PlayList(const QString & name,MusicDatabase* mdb);
	virtual ~PlayList();

	virtual void appendSong(Song* s);
	virtual void prependSong(Song* s);
	virtual void removeSong(Song* s);
	
	void setFilename(const QString & fn) {filename = fn;}
	QString getFilename() const {return filename;}
	
	bool save(const QString & filename);
	bool load(const QString & filename,MusicDatabase* mdb);
	
	typedef std::list<Song*>::iterator iterator;
	typedef std::list<Song*>::const_iterator const_iterator;
	
	iterator begin() {return songs.begin();}
	iterator end() {return songs.end();}
	
	const_iterator begin() const {return songs.begin();}
	const_iterator end() const {return songs.end();}
	
	bool empty() const {return songs.empty();}
	unsigned int size() const {return songs.size();}
	const QString & getName() const {return name;}
public:
	void autosave();
	
public slots:
	void onSongRemoved(Song* s);
	
signals:
	void changed();
	void songAdded(Song* s);
	void songRemoved(Song* s);
};

#endif
