/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <kglobal.h>
#include <kiconloader.h>
#include "playlistview.h"
#include "view/musiclistview.h"
#include "view/musiclistviewitem.h"
#include "musicdb/song.h"
#include "musicdb/musicdatabase.h"
#include "playlist.h"
#include "playlistviewmenu.h"

PlayListView::PlayListView(PlayList* pl,MusicDatabase* db,QWidget *parent, const char *name)
	: ChildView(pl->getName(),parent, name),pl(pl),db(db)
{
	connect(pl,SIGNAL(songAdded(Song* )),m_view,SLOT(addSong(Song* )));
	connect(pl,SIGNAL(songRemoved(Song* )),m_view,SLOT(removeSong(Song* )));
	
	for (PlayList::iterator i = pl->begin();i != pl->end();i++)
	{
		m_view->addSong(*i);
	}
	
	this->setMdiIcon(KGlobal::iconLoader()->loadIcon("sound",KIcon::Small));
	m_view->setAcceptDrops(true);
	connect(m_view,SIGNAL(songsDropped(const QStringList& )),
			this,SLOT(onSongsDropped(const QStringList& )));
}


PlayListView::~PlayListView()
{}

MusicListViewMenu* PlayListView::createContextMenu()
{
	return new PlayListViewMenu(this);
}

void PlayListView::removeSelection()
{
	QPtrList<QListViewItem> sel = m_view->selectedItems();
	if (sel.count() == 0)
		return;
	
	MusicListViewItem* si = (MusicListViewItem*)sel.first();
	while (si)
	{
		pl->removeSong(si->getSong());
		si = (MusicListViewItem*)sel.next();
	}
	
	pl->autosave();
}

void PlayListView::onSongsDropped(const QStringList & sl)
{
	for (QStringList::const_iterator i = sl.begin();i != sl.end();i++)
	{
		QString filename = *i;
		Song* s = db->getSong(filename);
		if (s)
		{
			pl->appendSong(s);
		}
	}
	
	pl->autosave();
}

#include "playlistview.moc"
