/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 ***************************************************************************/
#include <klocale.h>
#include <kiconloader.h>
#include <kglobal.h>
#include "playqueueview.h"

#include "songitem.h"
#include "player/musicplayer.h"
#include "player/playqueue.h"
#include "musicdb/song.h"
#include "musicdb/musicdatabase.h"
#include "view/songdragobject.h"
#include "pqviewmenu.h"


PlayQueueView::PlayQueueView(PlayQueue* pq,MusicDatabase* db)
		: KListView(0,"playqueue"),pmenu(0),pq(pq),db(db)
{
	connect(pq,SIGNAL(changed()),this,SLOT(updateView()));
	
	setCaption(i18n("Play Queue"));
	setIcon(KGlobal::iconLoader()->loadIcon("playqueue",KIcon::Small));
	
	addColumn(i18n("Title"));
	addColumn(i18n("Artist"));
	addColumn(i18n("Length"));
	
	setAcceptDrops(true);
	setDropHighlighter(true);
	setDragEnabled(true);
	setSelectionModeExt(FileManager);
	
	connect(
		this,SIGNAL(dropped(QDropEvent*, QListViewItem* )),
		this,SLOT(onDropped(QDropEvent*, QListViewItem* )));
	
	connect(
		this,SIGNAL(rightButtonClicked(QListViewItem*, const QPoint&, int )),
		this,SLOT(showContextMenu(QListViewItem*, const QPoint&, int )));
	
	connect(
		this,SIGNAL(doubleClicked(QListViewItem* )),
		this,SLOT(onDoubleClicked(QListViewItem* )));
}


PlayQueueView::~PlayQueueView()
{}


void PlayQueueView::updateView()
{
	clear();
	int idx = 0;
	for (PlayQueue::iterator i = pq->begin();i != pq->end();i++)
	{
		insertItem(new SongItem(this,*i,idx,false));
		idx++;
	}
}

QDragObject* PlayQueueView::dragObject()
{
	QPtrList<QListViewItem> sel = this->selectedItems();
	if (sel.count() == 0)
		return 0;
	
	std::list<int> indices;
	SongDragObject* sdo = new SongDragObject(this);
	SongItem* si = (SongItem*)sel.first();
	while (si)
	{
		indices.push_back(si->getIndex());
		sdo->addSong(si->getSong());
		si = (SongItem*)sel.next();
	}
	sdo->finalize();
	pq->removeItems(indices);
	return sdo;
}

void PlayQueueView::onDropped(QDropEvent* e,QListViewItem* after)
{	
	QString filelist;
	if (QTextDrag::decode(e,filelist) ) 
	{
		QStringList sl = QStringList::split("\n",filelist,false);
		SongItem* si = (SongItem*)after;
		int index = si == 0 ? -1 : si->getIndex();
		
		for (QStringList::iterator i = sl.begin();i != sl.end();i++)
		{
			QString filename = *i;
			Song* s = db->getSong(filename);
			if (s)
			{
				pq->insertAfter(index++,s);
			}
		}
	}
}

bool PlayQueueView::acceptDrag(QDropEvent* e) const
{
	bool tmp = QTextDrag::canDecode(e);
	e->accept(tmp);
	return tmp;
}

void PlayQueueView::removeSelected()
{
	QPtrList<QListViewItem> sel = this->selectedItems();
	if (sel.count() == 0)
		return;
	
	std::list<int> indices;
	SongItem* si = (SongItem*)sel.first();
	while (si)
	{
		indices.push_back(si->getIndex());
		si = (SongItem*)sel.next();
	}
	pq->removeItems(indices);
}

void PlayQueueView::showContextMenu(QListViewItem* ,const QPoint& pos, int )
{
	if (!pmenu)
		pmenu = new PQViewMenu(this);
	
	pmenu->popup(pos);
}

void PlayQueueView::onDoubleClicked(QListViewItem* item)
{
	SongItem* si = (SongItem*)item;
	if (si)
	{
		playNow(si->getSong());
	}
}

#include "playqueueview.moc"
