/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 ***************************************************************************/
#include <klocale.h>
#include <kiconloader.h>
#include <kglobal.h>
#include <klineedit.h>
#include <kmessagebox.h> 
#include <ktextedit.h>
#include <qvalidator.h>
#include <qcheckbox.h>
#include "tageditorimpl.h"
#include "globals.h"

TagEditorImpl::TagEditorImpl(QWidget* parent, const char* name, WFlags fl)
		: TagEditor(parent,name,fl)
{
	setCaption(i18n("Tag Editor"));
	setIcon(KGlobal::iconLoader()->loadIcon("id3tag",KIcon::Small));
	
	m_track_ed->setValidator(new QIntValidator(1,1000,this));
	m_year_ed->setValidator(new QIntValidator(0,3000,this));
	m_song = 0;
}

TagEditorImpl::~TagEditorImpl()
{}

bool TagEditorImpl::isEqual(const QString & a,const QString & b) const
{
	if (a.isEmpty() && b.isEmpty())
		return true;
	else
		return a == b;
}

bool TagEditorImpl::isModified() const
{
	if (!m_song)
		return false;
	
	if (!isEqual(m_album_ed->text(),m_song->getAlbum()))
		return true;
	
	if (!isEqual(m_title_ed->text(),m_song->getTitle()))
		return true;
	
	if (!isEqual(m_artist_ed->text(),m_song->getArtist()))
		return true;
	
	if (!isEqual(m_comment_ed->text(), m_song->getComment()))
		return true;
	
	if (!isEqual(m_genre_ed->text(),m_song->getGenre()))
		return true;
	
	QString year = m_song->getYear() > 0 ? QString("%1").arg(m_song->getYear()) : "";
	if (!isEqual(year,m_year_ed->text()))
		return true;
	
	QString track = m_song->getAlbumNr() > 0 ? QString("%1").arg(m_song->getAlbumNr()) : "";
	if (!isEqual(track,m_track_ed->text()))
		return true;
	
	return false;
}

void TagEditorImpl::savePressed()
{
	if (m_song)
	{
		Song* s = m_song;
		if (!m_remove_white_space->isChecked())
		{
			s->setAlbum(m_album_ed->text());
			s->setArtist(m_artist_ed->text());
			s->setTitle(m_title_ed->text());
			s->setGenre(m_genre_ed->text());
			s->setComment(m_comment_ed->text());
		}
		else
		{
			s->setAlbum(m_album_ed->text().stripWhiteSpace());
			s->setArtist(m_artist_ed->text().stripWhiteSpace());
			s->setTitle(m_title_ed->text().stripWhiteSpace());
			s->setGenre(m_genre_ed->text().stripWhiteSpace());
			s->setComment(m_comment_ed->text().stripWhiteSpace());
		}
		
		s->setAlbumNr(m_track_ed->text().toInt(0));
		s->setYear(m_year_ed->text().toInt(0));
		
		if (!m_song->saveInfoToFile())
			KMessageBox::error(this,
				i18n("Cannot save information to file %1").arg(s->getFilename()),
				i18n("Error"));
	}
}

void TagEditorImpl::setCurrentSong(Song* s)
{
	if (m_autosave->isChecked() && m_song && isModified())
	{
		savePressed();
	}

	if (m_song)
		disconnect(m_song,SIGNAL(destroyed()),this,SLOT(songWasDeleted()));
	
	m_song = s;
	connect(m_song,SIGNAL(destroyed()),this,SLOT(songWasDeleted()));
	
	bool rm_ws = m_remove_white_space->isChecked();
	if (!rm_ws)
	{
		m_title_ed->setText(s->getTitle());
		m_artist_ed->setText(s->getArtist());
		m_album_ed->setText(s->getAlbum());
		m_genre_ed->setText(s->getGenre());
		m_comment_ed->setText(s->getComment());
	}
	else
	{
		m_title_ed->setText(s->getTitle().stripWhiteSpace());
		m_artist_ed->setText(s->getArtist().stripWhiteSpace());
		m_album_ed->setText(s->getAlbum().stripWhiteSpace());
		m_genre_ed->setText(s->getGenre().stripWhiteSpace());
		m_comment_ed->setText(s->getComment().stripWhiteSpace());
	}
	
	if (s->getYear() > 0)
		m_year_ed->setText(QString("%1").arg(s->getYear()));
	else
		m_year_ed->setText("");
	
	if (s->getAlbumNr() > 0)
		m_track_ed->setText(QString("%1").arg(s->getAlbumNr()));
	else
		m_track_ed->setText("");
}

void TagEditorImpl::songWasDeleted()
{
	m_song = 0;
	m_title_ed->setText("");
	m_artist_ed->setText("");
	m_album_ed->setText("");
	m_genre_ed->setText("");
	m_comment_ed->setText("");
	m_year_ed->setText("");
	m_track_ed->setText("");
}



#include "tageditorimpl.moc"

