/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@student.luc.ac.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <kconfig.h>
#include <qcheckbox.h>
#include "tageditortool.h"
#include "tageditorimpl.h"
#include "kmusicmanager.h"
#include "mainwindow.h"
#include "view/childview.h"
#include "view/musiclistview.h"

TagEditorTool::TagEditorTool(KMusicManager* mm, const char* name)
	: Tool("tool/tageditor",mm, name),m_widget(0)
{
	
}


TagEditorTool::~TagEditorTool()
{
	delete m_widget;
}

void TagEditorTool::load()
{
	if (!m_widget)
	{
		KMusicManager* mm = getMusicMan();
		m_widget = new TagEditorImpl(0,"tageditorimpl");
		mm->getMainWindow()->addToolWindow(
				m_widget,KDockWidget::DockBottom,
				mm->getMainWindow()->getMainDockWidget(),35);
	}
}

void TagEditorTool::unload()
{
	delete m_widget;
	m_widget = 0;
}

void TagEditorTool::onChildViewAdded(ChildView* cv)
{
	connect(
			cv->getMusicListView(),SIGNAL(songSelected(Song* )),
			this,SLOT(setTagEditorSong(Song* )));
}

void TagEditorTool::setTagEditorSong(Song* s)
{
	m_widget->setCurrentSong(s);
}

void TagEditorTool::saveSettings(KConfig* cfg)
{
	cfg->setGroup(getToolName());
	cfg->writeEntry("remove_trailing_whitespace",
					m_widget->m_remove_white_space->isChecked());
	cfg->writeEntry("autosave",m_widget->m_autosave->isChecked());
}

void TagEditorTool::loadSettings(KConfig* cfg)
{
	cfg->setGroup(getToolName());
	m_widget->m_remove_white_space->setChecked(
			cfg->readBoolEntry("remove_trailing_whitespace",true));
	m_widget->m_autosave->setChecked(
			cfg->readBoolEntry("autosave",true));
}

#include "tageditortool.moc"
