/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@student.luc.ac.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <algorithm>  
#include <kconfig.h>
#include "toolmanager.h"
#include "tageditor/tageditortool.h"
#include "playqueue/playqueuetool.h"
#include "playlisted/playlisteditor.h"
#include "filerenamer/filerenamer.h"
#include "album/albumtool.h"
#include "treeview/treeviewtool.h"

ToolManager::ToolManager(KMusicManager* mm, const char* name) : Tool("tool/toolmanager",mm, name)
{
	PlayListEditor* ple = new PlayListEditor(mm);
	tools[ple->getToolName()] = ple;
	
	TagEditorTool* ted = new TagEditorTool(mm);
	tools[ted->getToolName()] = ted;
	
	PlayQueueTool* pqt = new PlayQueueTool(mm);
	tools[pqt->getToolName()] = pqt;
	
	TreeViewTool* tvt = new TreeViewTool(mm);
	tools[tvt->getToolName()] = tvt;
	
	FileRenamer* frn = new FileRenamer(mm);
	tools[frn->getToolName()] = frn;
	
 //	AlbumTool* abt = new AlbumTool(mm);
 //	tools[abt->getToolName()] = abt;
}


ToolManager::~ToolManager()
{
	for (ToolItr i = tools.begin();i != tools.end();i++)
	{
		Tool* t = i->second;
		delete t;
	}
}


void ToolManager::load()
{
	for (ToolItr i = tools.begin();i != tools.end();i++)
	{
		Tool* t = i->second;
		t->load();
	}
}

void ToolManager::onChildViewAdded(ChildView* cv)
{
	for (ToolItr i = tools.begin();i != tools.end();i++)
	{
		Tool* t = i->second;
		t->onChildViewAdded(cv);
	}
}

void ToolManager::unload()
{
	for (ToolItr i = tools.begin();i != tools.end();i++)
	{
		Tool* t = i->second;
		t->unload();
	}
}

void ToolManager::saveSettings(KConfig* cfg)
{
	for (ToolItr i = tools.begin();i != tools.end();i++)
	{
		Tool* t = i->second;
		t->saveSettings(cfg);
	}
}

void ToolManager::loadSettings(KConfig* cfg)
{
	for (ToolItr i = tools.begin();i != tools.end();i++)
	{
		Tool* t = i->second;
		t->loadSettings(cfg);
	}
}

Tool* ToolManager::getTool(const QString & name)
{
	ToolItr i = tools.find(name);
	return (i == tools.end()) ? 0 : i->second;
}


#include "toolmanager.moc"
