/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef TREEVIEW_H
#define TREEVIEW_H

#include <kfiletreeview.h>
#include <list>

class DBDir;
class MusicDatabase;
class TreeViewMenu;
class Song;

/**
@author Joris Guisson
*/
class TreeView : public KFileTreeView
{
	Q_OBJECT
public:
	TreeView(MusicDatabase* db,QWidget *parent = 0, const char *name = 0);
	virtual ~TreeView();
	
	QDragObject* dragObject();

private slots:
	void dirAdded(DBDir* dir);
	void dirRemoved(DBDir* dir);
	void addToPlayQueue();
	void createPlaylist();
	void deleteOnDisk();
	void renameSong();
	void showMenu(QListViewItem* item,const QPoint& pos, int col);
	void onDoubleClicked(QListViewItem* item);
	void onClicked(QListViewItem* item);
	
signals:
	/**
		The user wants to add a Song to the playqueue.
		@param s The Song
	 */
	void playNext(Song* s);
	
	/**
		The user wants to play a Song.
		@param s The Song
	 */
	void playNow(Song* s);
	
	/**
		The user wants to create a playlist.
		@param songs A list of songs, which should be added to the playlist
	 */
	void createPlaylist(const std::list<Song*>& songs);
	
	/**
		The user wants to rename a song.
		@param s The song
	 */
	void renameSong(Song* s);

	/**
		Set the current song in the tageditor.
		@param s The song
	 */
	void setCurrentSong(Song* s);
private:
	MusicDatabase* m_db;
	TreeViewMenu* m_menu;
};

#endif
