/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include "treeviewtool.h"
#include "treeview.h"
#include "kmusicmanager.h"
#include "mainwindow.h"
#include "musicdb/musicdatabase.h"
#include "player/musicplayer.h"

#include "tools/toolmanager.h"
#include "tools/playlisted/playlisteditor.h"
#include "tools/tageditor/tageditortool.h"
#include "tools/filerenamer/filerenamer.h"

TreeViewTool::TreeViewTool(KMusicManager* mm, const char* name)
	: Tool("tool/treeview", mm, name),m_view(0)
{}


TreeViewTool::~TreeViewTool()
{}


void TreeViewTool::load()
{
	if (m_view)
		return;
	
	KMusicManager* mm = getMusicMan();
	
	m_view = new TreeView(mm->getMusicDB(),mm->getMainWindow(),"treeview");
	
	mm->getMainWindow()->addToolWindow(
			m_view,KDockWidget::DockLeft,
			mm->getMainWindow()->getMainDockWidget(),35);
	
	PlayListEditor* pled = dynamic_cast<PlayListEditor*>(
			mm->getToolManager()->getTool("tool/playlisteditor"));
		
	TagEditorTool* ted = dynamic_cast<TagEditorTool*>(
			mm->getToolManager()->getTool("tool/tageditor"));
		
	FileRenamer* fren = dynamic_cast<FileRenamer*>(
			mm->getToolManager()->getTool("tool/filerenamer"));
	
	connect(m_view,SIGNAL(playNext(Song* )),mm->getPlayer(),SLOT(enqueueSong(Song* )));
	connect(m_view,SIGNAL(createPlaylist(const std::list< Song * >& )),
			pled,SLOT(createPlayList(const std::list< Song * >& )));
		
	connect(m_view,SIGNAL(playNow(Song* )),mm->getPlayer(),SLOT(playSong(Song* )));
		
	connect(m_view,SIGNAL(renameSong(Song* )),fren,SLOT(rename(Song* )));
	connect(m_view,SIGNAL(setCurrentSong(Song* )),ted,SLOT(setTagEditorSong(Song* )));
}

void TreeViewTool::unload()
{
	delete m_view;
	m_view = 0;
}

#include "treeviewtool.moc"
