/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <qlayout.h>
#include <klocale.h>
#include "searchbar.h"
#include "musiclistview.h"
#include "childview.h"
#include "musiclistviewmenu.h"

ChildView::ChildView(const QString &caption,QWidget *parent, const char *name)
		: QWidget(parent, name),m_caption(caption),m_menu(0),m_in_mdi(false),m_mdi_win(0)
{
	//// setup our layout manager to automatically add our widgets
	QVBoxLayout *top_layout = new QVBoxLayout(this);
	top_layout->setAutoAdd(true);
	
	m_sb = new SearchBar(this);
	m_view = new MusicListView(this);

	
	connect(
		m_sb,SIGNAL(searchTextChanged(const QString& )),
		m_view,SLOT(setSearchFilter(const QString & )));
	
	connect(
		m_view,SIGNAL(rightButtonClicked(QListViewItem*, const QPoint&, int )),
		this,SLOT(showContextMenu(QListViewItem*, const QPoint&, int )));
}


ChildView::~ChildView()
{}

MusicListViewMenu* ChildView::createContextMenu()
{
	return new MusicListViewMenu(m_view);
}

void ChildView::showContextMenu(QListViewItem* item,const QPoint& pos, int col)
{
	if (!m_menu)
	{
		m_menu = createContextMenu();
	}
	m_menu->setCurrent(item,col);
	m_menu->popup(pos);
}

void ChildView::updateView()
{
	m_view->updateView();
}

//////////////////////////////////////////////////////////////////

MdiChildView::MdiChildView(ChildView* cv,QWidget *parent, const char *name) 
	: KMdiChildView(cv->getMdiCaption(),parent,name),m_cv(cv)
{
	QVBoxLayout *top_layout = new QVBoxLayout(this);
	top_layout->add(m_cv);
	m_cv->reparent(this,QPoint(),true);
	m_cv->setMdiWin(this);
	m_cv->show();
	setIcon(m_cv->getMdiIcon());
}
	
MdiChildView::~MdiChildView()
{
	m_cv->reparent(0,QPoint(),false);
	m_cv->setMdiWin(0);
}

#include "childview.moc"
