/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <qlayout.h>
#include <klocale.h>
#include <stdlib.h>
#include <time.h>
#include <kconfig.h>
#include <musiclistviewmenu.h>
#include "musiclistview.h"
#include "musicdb/song.h"
#include "musiclistviewitem.h"
#include "songdragobject.h"
#include "util/iojobscheduler.h"
#include "util/iodeletejob.h"


MusicListViewConf MusicListView::m_vconf;

MusicListView::MusicListView(QWidget *parent, const char *name)
		: KListView(parent, name)
{
	m_num_shown = 0;

	//setItemsRenameable(true);	
	srand(time(0));
	
	connect(
		this,SIGNAL(doubleClicked(QListViewItem* )),
		this,SLOT(onSongDoubleClick(QListViewItem* )));
	
	connect(
		this,SIGNAL(clicked(QListViewItem* )),
		this,SLOT(onSelectionChanged(QListViewItem* )));
	
	setDragEnabled(true);
	setSelectionModeExt(FileManager);
	setShowSortIndicator(true);
	
	connect(this,SIGNAL(dropped(QDropEvent*, QListViewItem* )),
			this,SLOT(onDropped(QDropEvent*, QListViewItem* )));
	updateView();
	m_itr = QListViewItemIterator(this);
}


MusicListView::~MusicListView()
{}

void MusicListView::setViewConfig(const MusicListViewConf & vc)
{
	m_vconf = vc;
}

void MusicListView::addSong(Song* s)
{
	if (m_songs.find(s) != m_songs.end())
		return;
	
	MusicListViewItem* si = new MusicListViewItem(this,s);
	
	m_songs[s] = si;
	insertItem(si);
	if (s->matchesFilter(m_filter))
	{
		m_num_shown++;
	}
	else
	{
		takeItem(si);
		si->setTaken(true);
	}
	filtered(m_num_shown,getNumSongs());
}

void MusicListView::removeSong(Song* s)
{
	std::map<Song*,MusicListViewItem*>::iterator i = m_songs.find(s); 
	if (i == m_songs.end())
		return;
	
	if (s->matchesFilter(m_filter))
		m_num_shown--;
	
	delete i->second;
	m_songs.erase(i);
	filtered(m_num_shown,getNumSongs());
}

void MusicListView::clearView()
{
	std::map<Song*,MusicListViewItem*>::iterator i = m_songs.begin();
	while (i != m_songs.end())
	{
		MusicListViewItem* si = i->second;
		delete si;
		i++;
	}
	m_songs.clear();
}

void MusicListView::setSearchFilter(const QString & str)
{
	m_num_shown = 0;
	std::map<Song*,MusicListViewItem*>::iterator i = m_songs.begin();
	while (i != m_songs.end())
	{
		MusicListViewItem* si = i->second;
		Song* s = i->first;
		if (s->matchesFilter(str))
		{
			if (si->isTaken())
			{
				insertItem(si);
				si->setTaken(false);
			}
			m_num_shown++;
		}
		else 
		{
			if (!si->isTaken())
			{
				takeItem(si);
				si->setTaken(true);
			}
		}
		++i;
	}
	m_filter = str;
	filtered(m_num_shown,getNumSongs());
}

void MusicListView::updateView()
{
	unsigned int nc = this->columns();
	unsigned int i = 0;
	for (i = 0;i < m_vconf.getNumCols();i++)
	{
		if (i < nc)
			setColumnText(i,m_vconf.getColumnName(i));
		else
			addColumn(m_vconf.getColumnName(i));
		
		//int id = m_vconf.getColumnID(i);
		//setRenameable(i,id != VM_LENGTH && id != VM_FILENAME);
	}
	
	while (i < nc)
	{
		removeColumn(i);
		i++;
	}
	
	
	std::map<Song*,MusicListViewItem*>::iterator itr = m_songs.begin();
	while (itr != m_songs.end())
	{
		MusicListViewItem* si = itr->second;
		si->update();
		++itr;
	}
}

void MusicListView::refreshSelection()
{
	QPtrList<QListViewItem> sel = this->selectedItems();
	if (sel.count() == 0)
		return;
	
	MusicListViewItem* si = (MusicListViewItem*)sel.first();
	while (si)
	{
		si->getSong()->loadInfoFromFile();
		si->update();
		si = (MusicListViewItem*)sel.next();
	}
}

void MusicListView::onSongDoubleClick(QListViewItem* i)
{
	if (!i)
		return;
	
	Song* c = ((MusicListViewItem*)i)->getSong();
	m_itr = QListViewItemIterator(i);
	playNow(c);
}

void MusicListView::onSelectionChanged(QListViewItem* item)
{
	if (!item)
		return;
	
	Song* c = ((MusicListViewItem*)item)->getSong();
	songSelected(c);
}

Song* MusicListView::firstSong()
{
	if (m_songs.empty())
		return 0;
	
	m_itr = QListViewItemIterator(this);
	Song* c = ((MusicListViewItem*)m_itr.current())->getSong();
	return c;
}

unsigned int random_num(unsigned int max)
{
	float fr = (float)rand() / (RAND_MAX - 1);
	unsigned int n = (unsigned int)floor(fr * (max-1));
	if (n >= max)
		n = max / 2;
	return n;
}

Song* MusicListView::nextSong(bool random,bool repeat)
{
	if (m_songs.empty())
		return 0;
	
	if (random)
	{
		unsigned int na = random_num(m_songs.size());
		
		for (unsigned int i = 0;i < na;i++)
		{
			m_itr++;
			if (m_itr.current() == 0)
				m_itr = QListViewItemIterator(this);
		}
		
		
		MusicListViewItem* item = dynamic_cast<MusicListViewItem*>(m_itr.current());
		if (item)
			return item->getSong();
		else
			return 0;
	}
	else
	{
		m_itr++;
		if (m_itr.current())
		{
			MusicListViewItem* item = dynamic_cast<MusicListViewItem*>(m_itr.current());
			if (item)
				return item->getSong();
			else
				return 0;
		}
		else if (repeat)
		{
			m_itr = QListViewItemIterator(this);
			MusicListViewItem* item = dynamic_cast<MusicListViewItem*>(m_itr.current());
			if (item)
				return item->getSong();
			else
				return 0;
		}
		else
		{
			return 0;
		}
	}
}

void MusicListView::saveSettings(KConfig* cfg)
{
	cfg->writeEntry("sort_col",sortColumn());
}

void MusicListView::loadSettings(KConfig* cfg)
{
	int sort_col = cfg->readNumEntry("sort_col",0);
	setSortColumn(sort_col);
	updateView();
}

void MusicListView::addSelectionToPlayQueue()
{
	QPtrList<QListViewItem> sel = this->selectedItems();
	if (sel.count() == 0)
		return;
	
	MusicListViewItem* si = (MusicListViewItem*)sel.first();
	while (si)
	{
		playNext(si->getSong());
		si = (MusicListViewItem*)sel.next();
	}
}

QDragObject* MusicListView::dragObject()
{
	QPtrList<QListViewItem> sel = this->selectedItems();
	if (sel.count() == 0)
		return 0;
	
	SongDragObject* sdo = new SongDragObject(this);
	MusicListViewItem* si = (MusicListViewItem*)sel.first();
	while (si)
	{
		sdo->addSong(si->getSong());
		si = (MusicListViewItem*)sel.next();
	}
	sdo->finalize();
	return sdo;
}

void MusicListView::createPlayListFromSelection()
{
	QPtrList<QListViewItem> sel = this->selectedItems();
	if (sel.count() == 0)
		return;
	
	std::list<Song*> sels;
	
	MusicListViewItem* si = (MusicListViewItem*)sel.first();
	while (si)
	{
		sels.push_back(si->getSong());
		si = (MusicListViewItem*)sel.next();
	}
	
	createPlayList(sels);
}

void MusicListView::renameSelection()
{
	QPtrList<QListViewItem> sel = this->selectedItems();
	if (sel.count() == 0)
		return;
	
	std::list<Song*> sels;
	
	MusicListViewItem* si = (MusicListViewItem*)sel.first();
	while (si)
	{
		sels.push_back(si->getSong());
		si = (MusicListViewItem*)sel.next();
	}
	rename(sels);
}

void MusicListView::deleteSelection()
{
	QPtrList<QListViewItem> sel = this->selectedItems();
	if (sel.count() == 0)
		return;
	
	
	MusicListViewItem* si = (MusicListViewItem*)sel.first();
	while (si)
	{
		IOJobScheduler::instance().addJob(
				new IODeleteJob(si->getSong()->getFilename()));
		si = (MusicListViewItem*)sel.next();
	}
	
}

void MusicListView::onDropped(QDropEvent *e, QListViewItem*)
{
	QString filelist;
	if (QTextDrag::decode(e,filelist)) 
	{
		QStringList sl = QStringList::split("\n",filelist,false);
		songsDropped(sl);
	}
}

bool MusicListView::acceptDrag(QDropEvent* e) const
{
	bool tmp = QTextDrag::canDecode(e);
	e->accept(tmp);
	return tmp;
}

#include "musiclistview.moc"
