/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <kconfig.h>
#include <klocale.h>
#include <algorithm>
#include <qvaluelist.h>
#include "musiclistviewconf.h"

QString ColumnName(int i)
{
	switch (i)
	{
	case 0 :
		return i18n("Title");
	case 1 :
		return i18n("Artist");
	case 2 :
		return i18n("Length");
	case 3 :
		return i18n("Album");
	case 4 :
		return i18n("Track");
	case 5 :
		return i18n("Year");
	case 6 :
		return i18n("Genre");
	case 7 :
		return i18n("Filename");
	}
	return QString::null;
}


MusicListViewConf::MusicListViewConf()
{
	for (int i = 0;i < 8;i++)
	{
		if (i < 5)
			m_shown.push_back(Coll(ColumnName(i),i));
		else
			m_hidden.push_back(Coll(ColumnName(i),i));
	}
}

MusicListViewConf::MusicListViewConf(const MusicListViewConf & conf)
{
	m_shown = conf.m_shown;
	m_hidden = conf.m_hidden;
}


MusicListViewConf::~MusicListViewConf()
{}

MusicListViewConf & MusicListViewConf::operator = (const MusicListViewConf & conf)
{
	m_shown = conf.m_shown;
	m_hidden = conf.m_hidden;
	return *this;
}

void MusicListViewConf::show(const QString & name)
{
	CollItr i = m_hidden.begin();
	while (i != m_hidden.end())
	{
		if (i->name == name)
			break;
		i++;
	}
	
	if (i != m_hidden.end())
	{
		m_shown.push_back(*i);
		m_hidden.erase(i);
	}
}

void MusicListViewConf::hide(const QString & name)
{
	CollItr i = m_shown.begin();
	while (i != m_shown.end())
	{
		if (i->name == name)
			break;
		i++;
	}
	
	if (i != m_shown.end())
	{
		m_hidden.push_back(*i);
		m_shown.erase(i);
	}
}

void MusicListViewConf::moveUp(const QString & name)
{
	unsigned int i = 0;
	while (i < m_shown.size())
	{
		if (m_shown[i].name == name)
			break;
		i++;
	}
	
	if (i > 0 && i < m_shown.size())
	{
		Coll tmp = m_shown[i];
		m_shown[i] = m_shown[i-1];
		m_shown[i-1] = tmp;
	}
}

void MusicListViewConf::moveDown(const QString & name)
{
	unsigned int i = 0;
	while (i < m_shown.size())
	{
		if (m_shown[i].name == name)
			break;
		i++;
	}
	
	if (i < m_shown.size() -1)
	{
		Coll tmp = m_shown[i];
		m_shown[i] = m_shown[i+1];
		m_shown[i+1] = tmp;
	}
}

void MusicListViewConf::saveSettings(KConfig* cfg)
{
	cfg->setGroup("musiclistviewconf");
	QValueList<int> sl,hl;
	for (unsigned int i = 0;i < m_shown.size();i++)
	{
		sl.append(m_shown[i].id);
	}
	
	cfg->writeEntry("col_shown",sl);
	
	for (unsigned int i = 0;i < m_hidden.size();i++)
	{
		hl.append(m_hidden[i].id);
	}
	
	cfg->writeEntry("col_hidden",hl);
}

void MusicListViewConf::loadSettings(KConfig* cfg)
{
	cfg->setGroup("musiclistviewconf");
	QValueList<int> sl = cfg->readIntListEntry("col_shown");
	QValueList<int> hl = cfg->readIntListEntry("col_hidden");
	if (sl.size() == 0 || hl.size() == 0)
		return;
	
	m_shown.clear();
	m_hidden.clear();
	
	for (QValueList<int>::iterator i = sl.begin();i != sl.end();i++)
	{
		int v = *i;
		m_shown.push_back(Coll(ColumnName(v),v));
	}
	
	for (QValueList<int>::iterator i = hl.begin();i != hl.end();i++)
	{
		int v = *i;
		m_hidden.push_back(Coll(ColumnName(v),v));
	}
}
