/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef MUSICLISTVIEWCONF_H
#define MUSICLISTVIEWCONF_H

#include <vector>
#include <qstring.h>

class KConfig;

enum ViewMask
{
	VM_TITLE = 0,
	VM_ARTIST = 1,
	VM_LENGTH = 2,
	VM_ALBUM = 3,
	VM_ALBUM_NR = 4,
	VM_YEAR = 5,
	VM_GENRE = 6,
	VM_FILENAME = 7,
	
};

/**
@author Joris Guisson
*/
class MusicListViewConf
{
	struct Coll
	{
		QString name;
		int id;
		
		Coll(const QString & name,int id) : name(name),id(id) {}
		Coll(const Coll & c) : name(c.name),id(c.id) {}
		
		Coll & operator = (const Coll & c)
		{
			name = c.name;
			id = c.id;
			return *this;
		}
	};
	
	std::vector<Coll> m_shown;
	std::vector<Coll> m_hidden;
	
	typedef std::vector<Coll>::iterator CollItr;
public:
	MusicListViewConf();
	MusicListViewConf(const MusicListViewConf & conf);
	virtual ~MusicListViewConf();
	
	MusicListViewConf & operator = (const MusicListViewConf & conf);

	unsigned int getNumCols() const {return m_shown.size();}
	QString getColumnName(unsigned int i) const {return m_shown[i].name;}
	int getColumnID(unsigned int i) const {return m_shown[i].id;}
	
	unsigned int getNumHiddenCols() const {return m_hidden.size();}
	QString getHiddenColumnName(unsigned int i) const {return m_hidden[i].name;}
	
	void show(const QString & name);
	void hide(const QString & name);
	void moveUp(const QString & name);
	void moveDown(const QString & name);
	
	void saveSettings(KConfig* cfg);
	void loadSettings(KConfig* cfg);
};

#endif
