/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#include <qdatetime.h>
#include <qfileinfo.h>
#include "musiclistview.h"
#include "musicdb/song.h"
#include "util/error.h"
#include "globals.h"
#include "musiclistviewitem.h"

enum SortType
{
	TITLE = 0,
	ARTIST = 1,
	LENGTH = 2,
	ALBUM = 3,
	ALBUM_NR = 4,
	YEAR = 5,
	GENRE = 6,
	FILENAME = 7
};

template<class T>
int Compare(T a,T b)
{
	if (a < b)
		return -1;
	else if (a > b)
		return 1;
	else
		return 0;
}

MusicListViewItem::MusicListViewItem(MusicListView* parent,Song* s)
		: KListViewItem(parent),view(parent),song(s),taken(false)
{
	connect(song,SIGNAL(modified()),this,SLOT(update()));
	update();
}


MusicListViewItem::~MusicListViewItem()
{}

int MusicListViewItem::compare(QListViewItem * i,int col,bool ) const
{
	MusicListViewItem* it = (MusicListViewItem*)i;
	int ret = 0;
	switch (view->getViewConfig().getColumnID(col))
	{
	case TITLE :
		ret = Compare(song->getTitle(),it->song->getTitle());
		break;
	case ARTIST :
		ret = Compare(song->getArtist(),it->song->getArtist());
		break;
	case ALBUM :
		ret = Compare(song->getAlbum(),it->song->getAlbum());
		break;
	case ALBUM_NR :
		ret = Compare(song->getAlbumNr(),it->song->getAlbumNr());
		break;
	case YEAR :
		ret = Compare(song->getYear(),it->song->getYear());
		break;
	case LENGTH :
		ret = Compare(song->getLength(),it->song->getLength());
		break;
	case GENRE :
		ret = Compare(song->getGenre(),it->song->getGenre());
		break;
	case FILENAME :
		ret = Compare(song->getFilename(),it->song->getFilename());
		break;
	}

	return ret;
}

void MusicListViewItem::update()
{
	QTime t;
	t = t.addSecs(song->getLength());

	QString track;
	if (song->getAlbumNr())
		track = QString("%1").arg(song->getAlbumNr());

	QString year;
	if (song->getYear())
		year = QString("%1").arg(song->getYear());

	MusicListViewConf & vconf = view->getViewConfig();
	for (unsigned int i = 0;i < vconf.getNumCols();i++)
	{
		int id = vconf.getColumnID(i);
		switch (id)
		{
		case VM_TITLE:
			if (song->getTitle().isEmpty())
			{
				QFileInfo fi(song->getFilename());
				setText(i,fi.fileName());
			}
			else
				setText(i,song->getTitle());
			break;
		case VM_ARTIST:
			setText(i,song->getArtist());
			break;
		case VM_LENGTH:
			setText(i,t.toString("mm:ss"));
			break;
		case VM_ALBUM:
			setText(i,song->getAlbum());
			break;
		case VM_ALBUM_NR:
			setText(i,track);
			break;
		case VM_YEAR:
			setText(i,year);
			break;
		case VM_GENRE:
			setText(i,song->getGenre());
			break;
		case VM_FILENAME:
			setText(i,song->getFilename());
			break;
		}
	}
}

void MusicListViewItem::changeItem(int col,const QString & str)
{
	MusicListViewConf & vconf = view->getViewConfig();
	switch (vconf.getColumnID(col))
	{
	case VM_TITLE:
		song->setTitle(str);
		break;
	case VM_ARTIST:
		song->setArtist(str);
		break;
	case VM_ALBUM:
		song->setAlbum(str);
		break;
	case VM_ALBUM_NR:
		{
			bool ok;
			int track = str.toInt(&ok);
			if (ok)
				song->setAlbumNr(track);
		}
		break;
	case VM_YEAR:
		{
			bool ok;
			int year = str.toInt(&ok);
			if (ok)
				song->setYear(year);
		}
		break;
	case VM_GENRE:
		song->setGenre(str);
		break;
	case VM_LENGTH:
		break;
	case VM_FILENAME:
		break;
	}

	try
	{
		song->saveInfoToFile();
	}
	catch (Error & e)
	{
		OutputLog() << "Error : " << e.errorMessage() << endl;
	}
	update();
}


#include "musiclistviewitem.moc"
