/***************************************************************************
 *   Copyright (C) 2004 by Joris Guisson                                   *
 *   joris.guisson@pandora.be                                              *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   This program is distributed in the hope that it will be useful,       *
 *   but WITHOUT ANY WARRANTY; without even the implied warranty of        *
 *   MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the         *
 *   GNU General Public License for more details.                          *
 *                                                                         *
 *   You should have received a copy of the GNU General Public License     *
 *   along with this program; if not, write to the                         *
 *   Free Software Foundation, Inc.,                                       *
 *   59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.             *
 ***************************************************************************/
#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <map>
#include <kmdimainfrm.h>

class KMusicManager;
class ChildView;
class TrayIcon;
class KMdiChildView;
class MMStatusBar;
class ActionCollection;

/**
@author Joris Guisson
*/
class MainWindow : public KMdiMainFrm
{
	Q_OBJECT
public:
	MainWindow(KMusicManager* mm);
	~MainWindow();
	
	void addChildView(ChildView* cv,const QString & name);
	void removeChildView(const QString & name);
	ChildView* getChildView(const QString & name);
	void activateChildView(const QString & name);
	void hideChildView(const QString & name);
	void showChildView(const QString & name);
	
	void saveCVSettings(KConfig* cfg);
	void loadCVSettings(KConfig* cfg);
	
	bool isSystemTrayIconEnabled() const {return m_enable_systray_icon;}
	
	void setActionStatus(bool random,bool repeat);
	
	ActionCollection* getActionCollection() {return m_act_col;}
	
public slots:
	void updateChildViews();
	void onViewActivated(KMdiChildView* cv);
	void enableSysTrayIcon(bool yes);
	void optionsShowToolbar();
	void optionsShowStatusbar();
	void optionsConfigureKeys();
	void optionsConfigureToolbars();
	void optionsPreferences();
	void newToolbarConfig();
	void onFiltered(int num,int tot);

private:
	void childWindowCloseRequest(KMdiChildView* wnd);
	void createPlayToolBar();
	bool queryClose();
	bool queryExit();
	
signals:
	void filtered(int num,int tot);
	
private:
	KMusicManager* m_music_manager;
	TrayIcon* m_tray_icon;
	bool m_enable_systray_icon;
	ActionCollection* m_act_col;
	MMStatusBar* m_sb;
	
	
	std::map<QString,ChildView*> m_views;
	
	bool m_first_boot;
	
	typedef std::map<QString,ChildView*>::iterator CVItr;
	
	friend class KMusicManager;
};

#endif
